package com.sincere.student.service.impl;

import com.github.pagehelper.PageHelper;
import com.sincere.student.dto.MajorSearchDto;
import com.sincere.student.mapper.MajorMapper;
import com.sincere.student.model.Major;
import com.sincere.student.service.MajorService;
import com.sincere.student.utils.Page;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class MajorServiceImpl implements MajorService {

    @Autowired
    MajorMapper majorMapper;

    @Override
    public Page<Major> getList(MajorSearchDto majorSearchDto) {
        Page<Major> page = new Page<>(majorSearchDto.getPage(), majorSearchDto.getPageSize());
        Major major = new Major();
        if (StringUtils.isNotBlank(majorSearchDto.getSearch())) {
            major.setMajor("%" + majorSearchDto.getSearch() + "%");
        }
        if (majorSearchDto.getPid() != 0) {
            major.setPid(majorSearchDto.getPid());
        }
        PageHelper.startPage(majorSearchDto.getPage(), majorSearchDto.getPageSize());
        List<Major> list = majorMapper.getList(major);
        page.setList(list);
        page.setCount(majorMapper.getListCount(major));
        return page;
    }

    @Override
    public Major getById(int id) {
        return majorMapper.getById(id);
    }

    @Override
    public int create(Major major) {
        if (major.getPid() == 0) { //说明是一级专业
            major.setPid(-1);
        }
        return majorMapper.create(major);
    }

    @Override
    public int update(Major major) {
        return majorMapper.update(major);
    }

    @Override
    public int delete(int id) {
        majorMapper.delete(id);
        majorMapper.deleteByPid(id);
        return 1;
    }

    @Override
    public List<Major> selectMajor() {
        return majorMapper.selectMajor();
    }
}
